#
# spec file for package rcs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rcs
Version:        5.10.1
Release:        4.4
Summary:        Revision Control System
License:        GPL-3.0-or-later
Group:          Development/Tools/Version Control
URL:            https://www.gnu.org/software/rcs/
Source:         https://ftp.gnu.org/pub/gnu/rcs/%{name}-%{version}.tar.lz
Source1:        https://ftp.gnu.org/pub/gnu/rcs/%{name}-%{version}.tar.lz.sig
Source2:        rcs.keyring
Patch0:         reproducible-build.diff
Patch1:         rcs-configure-c99.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  ed
BuildRequires:  groff
BuildRequires:  lzip
Requires:       diffutils

%description
RCS, the Revision Control System, manages multiple revisions of files.
RCS can store, retrieve, log, identify, and merge revisions. It is
useful for files that are frequently revised, for example: programs,
documentation, graphics, and papers.

%prep
%autosetup -p1

%build
autoreconf -f
ac_cv_path_SENDMAIL=%{_sbindir}/sendmail \
%configure
%make_build

%check
%make_build check

%install
%make_install
mkdir -p %{buildroot}%{_defaultdocdir}/rcs

%files
%{_defaultdocdir}/rcs
%{_bindir}/*
%license COPYING
%doc AUTHORS README NEWS THANKS ChangeLog
%{_mandir}/man?/*.gz
%{_infodir}/*.*

%changelog
* Tue Oct  1 2024 Manfred Schwarb <manfred99@gmx.ch>
- remove patch rcs-glibc-2.34.patch, all current repos seem to build
    fine without it, and use %%autosetup
- make build more reproducible: patch reproducible-build.diff, taken from debian
- make configure.ac C99 compliant: patch rcs-configure-c99.patch, taken from fedora,
    and add code to rebuild configure.
- drop configure option --with-diff-utils (always defunct as it should have been
  - -with-diffutils). --with-diffutils has been removed in rcs 5.8.
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Mar 28 2022 Dirk Müller <dmueller@suse.com>
- use https for urls
* Mon Feb  7 2022 Andreas Stieger <andreas.stieger@gmx.de>
- rcs 5.10.1:
  * handle unexpected byte in edit script (rlog)
  * portability fix: use ‘SIGSTKSZ’ more gingerly
  * misc portability tweaks via gnulib
- remove obsolete texinfo packaging macros
* Mon Sep 27 2021 Stefan Dirsch <sndirsch@suse.com>
- rcs-glibc-2.34.patch
  * workaround to fix build against glibc 2.34
* Fri Oct 23 2020 Andreas Stieger <andreas.stieger@gmx.de>
- rcs 5.10.0:
  * Fix RCS file search skipping RCS/FILENAME by default
  * Fix 'rlog -w' omitting 'w' when specified without login
  * preserve subsecond mtime on file systems that support it
* Wed Jan 13 2016 tchvatal@suse.com
- Use %%configure and %%make_install macros
- Clean up with spec-cleaner
* Thu Jun 18 2015 crrodriguez@opensuse.org
- Use -std=gnu99, use of C11 keywords is incorrect and build
  fails with GCC5
* Fri Jan 23 2015 sndirsch@suse.com
- specfile: added rcs.keyring as source
* Fri Jan 23 2015 andreas.stieger@gmx.de
- rcs 5.9.4:
  + documentation improvements
* Sat Oct 11 2014 andreas.stieger@gmx.de
- rcs 5.9.3:
  - compatibility w/ RCS 2.x file format dropped
  - fix crash on co/ci without changes on a branch
- includes changes from 5.9.2:
  - avoid possibly failing command in backticks
  - handle low-memory situations like RCS 5.7 (mostly)
  - default for env var ‘RCS_MEM_LIMIT’ relaxed
- includes changes from 5.9.1:
  - avoid ‘grep -q’
  - ‘PROGRAM --help’ shows home page / "gethelp" info
- includes changes from 5.9.0:
  - common option ‘-V’ obsoleted by ‘--version’
  - ‘rcsmerge --help’ mentions ‘-A’, ‘-E’, ‘-e’
  - ‘ident -VN’ and ‘merge -VN’ now signal error
  - ident(1) recognizes Subversion "fixed-width keyword syntax"
  - new co(1) option ‘-S’ for "self-same" mode
  - several RCS commands "internalized" into rcs(1)
  - ‘--help’ output includes a one-line description
  - effects of ‘-VN’ (N ∈ {3,4,5}) documented
- includes changes from 5.8.2:
  - fix wrong symbolic name dereference
  - ‘integrity’ value syntax better specified
  - New manual chapter: RCS file format
  - Manpages refer to info documentation
  - Script to trim "junk at end of file" posted
- includes changes from 5.8.1:
  - Debug output removed
  - Criteria for avoiding read-only checks refined
  - fix regression in ‘-zLT’ handling
  - fix regression in ‘ci -d -T’ handling
  - Use ‘diff --label’ instead of ‘diff -L’
  - Documentation improvements
- verify source signature
- reformat spec file
- licence is now GPL-3.0+
- drop rcs-rlog-zLT.patch, rcs-stdio.in.patch: upstream
* Mon Dec 17 2012 sndirsch@suse.com
- rcs-rlog-zLT.patch
  * fix output of "rlog -zLT" on x86_64 (bnc#784948)
* Tue Jul 17 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Thu Oct 20 2011 giecrilj@stegny.2a.pl
- Better URL, %%check as documented
* Wed Oct 19 2011 coolo@suse.com
- remove old sources
* Mon Oct 17 2011 giecrilj@stegny.2a.pl
- bump version to 5.8
- add documentation
* Mon May 21 2007 sndirsch@suse.de
- fixed sendmail path (Bug #275541)
* Mon Sep  4 2006 rguenther@suse.de
- Get rid of postfix build dependency, use /sbin/sendmail.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
- Don't build as root.
* Fri Mar 26 2004 ro@suse.de
- added postfix to neededforbuild
* Wed Apr 23 2003 coolo@suse.de
- use BuildRoot
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Jan 10 2001 werner@suse.de
- Add temp file patch of Olaf Kirch
* Fri Nov 17 2000 fehr@suse.de
- set group tag
* Mon May 22 2000 fehr@suse.de
- add HTML-Documentation to /usr/share/doc/packages/src
* Fri Feb 25 2000 schwab@suse.de
- /usr/man -> /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Oct 24 1997 ro@suse.de
- checking re enabled, done instead:
  changed mode of src-dir to 777 and su -c make nobody
* Thu Oct 23 1997 ro@suse.de
- disabled checking for root-rights in conf.sh
  ready for autobuild
